package com.bocloud.sms.booter.controller;

import com.bocloud.sms.entity.Label;
import com.bocloud.sms.interfaces.LabelService;
import com.megatron.common.model.*;
import com.megatron.common.utils.Common;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

/**
 * @author zhangdi
 * @since 2018/7/2
 */
@RestController
@RequestMapping("/v1/tags")
@Tag(name = "标签管理")
public class LabelController {

    private final LabelService labelService;

    public LabelController(LabelService labelService) {
        this.labelService = labelService;
    }

    /**
     * 获取标签列表
     *
     * @param pager 分页参数
     * @return 标签列表
     */
    @Operation(summary = "获取命名规则列表")
    @GetMapping
    public GeneralResult<GridBean<Label>> list(Pager pager, @Value(Common.REQ_CONTEXT) RequestContext context) {
        return labelService.list(pager, context);
    }

    /**
     * 添加标签
     *
     * @param label 标签
     * @return 添加结果
     */
    @Operation(summary = "添加标签")
    @PostMapping
    public GeneralResult<Label> create(@RequestBody Label label, @Value(Common.REQ_CONTEXT) RequestContext context) {
        return labelService.create(label, context);
    }

    /**
     * 修改标签
     *
     * @param id    标签id
     * @param label 标签
     * @return 修改结果
     */
    @Operation(summary = "修改标签")
    @PutMapping("/{id}")
    public GeneralResult<Label> modify(@PathVariable(value = Common.ID) Long id, @RequestBody Label label) {
        label.setId(id);
        return labelService.modify(label);
    }

    /**
     * 删除标签
     *
     * @param id 标签id
     * @return 删除结果
     */
    @Operation(summary = "删除标签")
    @DeleteMapping("/{id}")
    public Result remove(@PathVariable(value = Common.ID) Long id) {
        return labelService.remove(id);
    }

    /**
     * 查看标签详情
     *
     * @param id 标签id
     * @return 标签
     */
    @Operation(summary = "查看标签详情")
    @GetMapping("/{id}")
    public GeneralResult<Label> detail(@PathVariable(value = Common.ID) Long id) {
        return labelService.detail(id);
    }
}