package com.bocloud.sms.interfaces;

import com.bocloud.sms.entity.Business;
import com.bocloud.sms.entity.Project;
import com.bocloud.sms.model.BusinessModel;
import com.megatron.common.model.*;
import jakarta.servlet.http.HttpServletResponse;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * @author tyl
 * @time 2020/6/2 周二 15:57
 */
public interface BusinessService {
    /**
     * 分页查询业务列表
     *
     * @param pager
     * @param requestContext
     * @return
     */
    GeneralResult<GridBean<Business>> list(Pager pager, RequestContext requestContext);

    /**
     * 创建业务
     *
     * @param params
     * @param user
     * @return
     */
    Result create(BusinessModel params, RequestContext user);

    /**
     * 修改业务
     *
     * @param id
     * @param params
     * @param user
     * @return
     */
    Result modify(Long id, BusinessModel params, RequestContext user);

    /**
     * 查看业务详情
     *
     * @param id
     * @return
     */
    GeneralResult<Business> detail(Long id);

    /**
     * 删除业务
     *
     * @param id
     * @param user
     * @return
     */
    Result remove(Long id, RequestContext user);

    /**
     * 批量删除业务
     *
     * @param ids
     * @param requestContext
     * @return
     */
    Result batchRemove(List<Long> ids, RequestContext requestContext);

    /**
     * 获取业务下的项目
     *
     * @param id
     * @return
     */
    GeneralResult<List<Project>> listBusinessProject(Long id);

    /**
     * 业务操作
     *
     * @param id
     * @param projectIds
     * @return
     */
    Result businessAction(Long id, List<Long> projectIds);

    /**
     * 业务导入模板
     *
     * @param title
     * @param requestContext
     * @return
     */
    XSSFWorkbook importTemp2(String title, RequestContext requestContext);


    /**
     * 业务导入模板
     *
     * @param response
     * @return
     */
    Result importTemp(HttpServletResponse response);


    /**
     * 业务数据导入
     *
     * @param multipartFile
     * @param requestContext
     * @return
     */
    Result importData(MultipartFile multipartFile, RequestContext requestContext);

    /**
     * 业务数据导出
     *
     * @param paramList
     * @param requestContext
     * @return
     */
    XSSFWorkbook export(List<Param> paramList, RequestContext requestContext);

}
