package com.bocloud.sms.interfaces;

import com.alibaba.fastjson.JSONArray;
import com.bocloud.sms.entity.Role;
import com.bocloud.sms.entity.User;
import com.bocloud.sms.model.ApiInfo;
import com.bocloud.sms.model.CloudServiceBean;
import com.bocloud.sms.model.RoleModel;
import com.megatron.common.exception.InternalServerException;
import com.megatron.common.model.*;

import java.util.List;

/**
 * 角色抽象Service接口
 *
 * @author tyl
 */
public interface RoleService {

    /**
     * 创建角色
     *
     * @param roleModel
     * @param requestContext
     * @return
     * @throws InternalServerException
     */
    Result create(RoleModel roleModel, RequestContext requestContext) throws InternalServerException;

    /**
     * 修改角色信息
     *
     * @param id
     * @param roleModel
     * @param requestContext
     * @return
     * @throws InternalServerException
     */
    Result modify(Long id, RoleModel roleModel, RequestContext requestContext) throws InternalServerException;

    /**
     * 删除角色
     *
     * @param id
     * @param requestContext
     * @return
     * @throws InternalServerException
     */
    Result remove(Long id, RequestContext requestContext) throws InternalServerException;

    /**
     * 查询角色详情
     *
     * @param id
     * @return
     */
    GeneralResult<Role> detail(Long id);

    /**
     * 授权角色权限
     *
     * @param id
     * @param ids
     * @param requestContext
     * @return
     * @throws InternalServerException
     */
    Result accredit(Long id, List<Long> ids, RequestContext requestContext) throws InternalServerException;

    /**
     * 查询角色列表
     *
     * @param pager
     * @param requestContext
     * @return
     */
    GeneralResult<GridBean<Role>> list(Pager pager, RequestContext requestContext);

    /**
     * 查询角色权限
     *
     * @param id
     * @param menu
     * @param tenant
     * @param requestContext
     * @return
     */
    GeneralResult<List<CloudServiceBean>> listPermissions(Long id, boolean menu, boolean tenant, RequestContext requestContext);

    /**
     * 查询角色是否存在
     *
     * @param name
     * @param tenantId
     * @return
     */
    Result exists(String name, Long tenantId);

    /**
     * 获取请求用户角色信息
     *
     * @param requestContext
     * @return
     */
    GeneralResult<List<Long>> roleIds(RequestContext requestContext);

    /**
     * API权限授权角色
     *
     * @param id
     * @param module
     * @param apiList
     * @return
     */
    Result accreditRole(Long id, List<ApiInfo> apiList);

    /**
     * 获取API权限列表
     *
     * @param id
     * @param tags
     * @return
     */
    GeneralResult<JSONArray> getApiPermission(Long id, String tags);

    /**
     * 查询指定角色下的用户
     *
     * @param pager
     * @param id
     * @return
     */
    GeneralResult<GridBean<User>> listUsersByRoleId(Pager pager, Long id);
}
