package com.bocloud.sms.service;

import com.bocloud.sms.entity.Icon;
import com.bocloud.sms.interfaces.IconService;
import com.bocloud.sms.repository.IconRepository;
import com.megatron.common.model.*;
import com.megatron.common.utils.GridHelper;
import com.megatron.framework.lock.AutoCloseLock;
import com.megatron.framework.lock.LockFactory;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Optional;
import java.util.concurrent.TimeUnit;

/**
 * 图表service实现层
 *
 * @author 胡立伟
 * @Version 1.0
 * @since 2020年4月7日
 */
@Slf4j
@Service("iconService")
public class IconServiceImpl implements IconService {

    @Autowired
    private LockFactory lockFactory;
    @Autowired
    private IconRepository iconRepository;

    @Override
    public GeneralResult<GridBean<Icon>> list(Pager pager, RequestContext context) {
        try {
            pager.setParams(Optional.ofNullable(pager.getParams()).orElse(new ArrayList<>()));
            pager.setSorter(Optional.ofNullable(pager.getSorter()).orElse(new HashMap<>()));
            List<Param> params = pager.getParams();
            int total = this.iconRepository.count(params);
            List<Icon> list = this.iconRepository.list(pager);
            GridBean<Icon> gridBean = GridHelper.getBean(pager.getPage(), pager.getRows(), total, list);
            return new GeneralResult<>(true, gridBean, "查询成功");
        } catch (Exception e) {
            log.error("Query notice icon list fail:", e);
            return new GeneralResult<>(false, "查询失败");
        }
    }

    @Override
    public GeneralResult<Void> create(MultipartFile[] files, String category, RequestContext requestContext) {
        try {
            MultipartFile item = files[0];
            Icon icon = new Icon();
            icon.setName(URLDecoder.decode(item.getName(), "UTF-8"));
            byte[] data = IOUtils.toByteArray(item.getInputStream());
            icon.setIcon("data:image/png;base64," + Base64.encodeBase64String(data));
            icon.setReserved(false);
            icon.setCreatorId(requestContext.getTarget());
            icon.setMenderId(requestContext.getTarget());
            icon.setCategory(category);
            this.iconRepository.save(icon);
            return new GeneralResult<>(true, "添加成功");
        } catch (Exception e) {
            log.error("Create notice icon error:", e);
            return new GeneralResult<>(false, "添加失败");
        }
    }

    @SneakyThrows
    @Override
    public GeneralResult<Void> remove(Long id) {
        String path = Icon.class.getSimpleName() + "_" + id;
        AutoCloseLock lock = lockFactory.getACLock(path);
        try {
            if (!lock.acquire(10, TimeUnit.SECONDS)) {
                log.warn("Get harmonyLock time out!");
                return new GeneralResult<>(false, "请求超时");
            }
            Icon icon = iconRepository.query(id);
            if (icon == null) {
                return new GeneralResult<>(false, "图标不存在");
            }
            if (icon.getReserved().equals(true)) {
                return new GeneralResult<>(false, "此图标不可删除");
            }
            this.iconRepository.delete(id);
            return new GeneralResult<>(true, "删除成功");
        } catch (Exception e) {
            log.error("Remove notice icon fail:", e);
            return new GeneralResult<>(false, "删除失败");
        } finally {
            lock.close();
        }
    }

}
