package com.bocloud.sms.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.megatron.common.utils.DateDeserializer;
import com.megatron.common.utils.DateSerializer;
import com.megatron.entity.annotations.Column;
import com.megatron.entity.annotations.IgnoreAll;
import com.megatron.entity.annotations.PK;
import com.megatron.entity.annotations.Table;
import com.megatron.entity.bean.GenericEntity;
import com.megatron.entity.meta.PKStrategy;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 自服务用户
 *
 * @author wangyu
 * @version 1.0
 * @since 2020年1月29日
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Table("users")
public class User extends GenericEntity {
    /**
     * id
     */
    @PK(value = PKStrategy.AUTO)
    private Long id;
    /**
     * 账号
     */
    @Column("account")
    private String account;
    /**
     * 密码
     */
    @JsonIgnore
    @Column("password")
    private String password;
    /**
     * 邮件
     */
    @Column("email")
    private String email;
    @Column("phone")
    private String phone;
    /**
     * 联系方式
     */
    @Column("mobile")
    private String mobile;
    /**
     * 登录状态
     */
    @Column("login_status")
    private Boolean loginStatus;
    /**
     * 公司名称
     */
    @Column("company")
    private String company;
    /**
     * sessionId
     */
    @Column("session_id")
    private String sessionId;
    @IgnoreAll
    private String tenantName;
    @IgnoreAll
    private String tenantAccount;
    @IgnoreAll
    private BigDecimal discount;
    /**
     * 所属租户id
     */
    @Column("tenant_id")
    private Long tenantId;
    @IgnoreAll
    private List<String> roleNames;
    /**
     * 所属组织id
     */
    @Column("depart_id")
    private Long departId;


    /**
     * 所属组织id
     */
    @Column("depart_ids")
    private String departIds;
    /**
     * 所属组织名称
     */
    @IgnoreAll
    private String departmentName;
    @IgnoreAll
    private Boolean checked;
    @IgnoreAll
    private Boolean projectManager;
    /**
     * 用户工号
     */
    @Column("job_number")
    private String jobNumber;
    @Column("sex")
    private Boolean sex;
    @Column("is_manager")
    private Boolean isManager;

    /**
     * 过期时间
     */
    @Column("expired_date")
    @JsonSerialize(using = DateSerializer.class)
    @JsonDeserialize(using = DateDeserializer.class)
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date expiredDate;
    @IgnoreAll
    private Long projectId;
    @IgnoreAll
    private List<Long> projectIds;
    /**
     * 头像
     */
    @Column("portrait")
    private String portrait;
    /**
     * 用户来源
     */
    @Column("origin")
    private String origin;
    @Column("last_pwd_modify_date")
    @JsonSerialize(using = DateSerializer.class)
    @JsonDeserialize(using = DateDeserializer.class)
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date lastPwdModifyDate;

    @Column("last_login_date")
    @JsonSerialize(using = DateSerializer.class)
    @JsonDeserialize(using = DateDeserializer.class)
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date lastLoginDate;
    /**
     * 企业微信唯一标识userId
     */
    @Column("wechat")
    private String wechat;
    /**
     * 钉钉唯一标识userId
     */
    @Column("dingtalk")
    private String dingtalk;
    /**
     * 云服务商ID
     */
    @Column("service_address_id")
    private Long serviceAddressId;

    /**
     * 单点登录用户唯一标识
     */
    @Column("user_id")
    private String userId;

    public User(String name, String account, String email, String company, String mobile, Long creatorId, Long tenantId) {
        this.setName(name);
        this.setCreatorId(creatorId);
        this.account = account;
        this.company = company;
        this.email = email;
        this.mobile = mobile;
        this.tenantId = tenantId;
    }
}
