package com.bocloud.sms.repository;

import com.megatron.database.core.intf.impl.JdbcGenericDao;
import com.megatron.database.utils.QueryBuilder;
import com.bocloud.sms.entity.UpgradeTask;
import com.megatron.common.model.Pager;
import com.megatron.common.model.Param;
import com.megatron.framework.core.CurrentService;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * 系统升级历史
 *
 * @author luyanchao
 * @date 2021-06-15
 */
@Repository("upgradeTaskRepository")
public class UpgradeTaskRepository extends JdbcGenericDao<UpgradeTask, Long> {

    public UpgradeTaskRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    /**
     * 分页查询系统升级历史
     *
     * @param pager 分页参数
     * @return 数据列表
     */
    public List<UpgradeTask> list(Long upgradeHistoryId, Pager pager) {
        String sql = "select a.* from upgrade_task a where a.is_deleted = 0 ";
        Map<String, Object> paramMap = getQueryBuilder().getParam(pager.getParams());
        if (upgradeHistoryId != null) {
            sql += " and a.upgrade_history_id = :upgradeHistoryId ";
            paramMap.put("upgradeHistoryId", upgradeHistoryId);
        }
        getQueryBuilder().build(sql, pager, "a");
        return this.list(UpgradeTask.class, sql, paramMap);
    }

    /**
     * 查询系统升级历史数量
     *
     * @param params 查询参数
     * @return 数量
     */
    public int count(Long upgradeHistoryId, List<Param> params) {
        String sql = "select count(1) from upgrade_task a where a.is_deleted = 0 ";
        Map<String, Object> paramMap = getQueryBuilder().getParam(params);
        if (upgradeHistoryId != null) {
            sql += " and a.upgrade_history_id = :upgradeHistoryId ";
            paramMap.put("upgradeHistoryId", upgradeHistoryId);
        }
        getQueryBuilder().build(sql, params, null, "a");
        return this.countQuery(sql, paramMap).intValue();
    }

    /**
     * 按id查询系统升级任务
     *
     * @param id 查询参数
     * @return 系统升级任务
     */
    public UpgradeTask get(Long id) {
        String sql = "select a.* from upgrade_task a where a.is_deleted = 0 and id = :id ";
        Map<String, Object> paramMap = Collections.singletonMap("id", id);
        return this.list(UpgradeTask.class, sql, paramMap).stream().findFirst().orElse(null);
    }
}
