package com.bocloud.sms.repository;

import com.bocloud.sms.entity.UserGroupRelation;
import com.megatron.common.utils.MapTools;
import com.megatron.database.core.intf.impl.BasicGenericDao;
import com.megatron.framework.core.CurrentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author hongqingyu
 * @time 2022/06/14 20:04
 */
@Repository("userGroupRelationRepository")
public class UserGroupRelationRepository extends BasicGenericDao<UserGroupRelation, Long> {
    @Autowired
    public UserGroupRelationRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    /**
     * 根据用户组id删除关系
     *
     * @param groupId 用户组id
     */
    public void deleteByGroupId(Long groupId) {
        String sql = " delete from user_group_relation where user_group_id =:groupId ";
        Map<String, Object> params = MapTools.simpleMap("groupId", groupId);
        this.execute(sql, params);
    }

    /**
     * 根据用户组id删除关系
     *
     * @param userIds 用户id
     * @param groupId 用户组id
     */
    public void deleteByGroupId(Long groupId, List<Long> userIds) {
        String sql = " delete from user_group_relation where user_group_id =:groupId and user_id in (:userIds) ";
        Map<String, Object> params = MapTools.simpleMap("groupId", groupId);
        params.put("userIds", userIds);
        this.execute(sql, params);
    }

    /**
     * 根据用户组id查询用户id
     *
     * @param groupId 用户组id
     * @return 关系列表
     */
    public List<Long> listUserIdByGroupId(Long groupId) {
        String sql = " select * from user_group_relation where user_group_id =:groupId  ";
        Map<String, Object> params = MapTools.simpleMap("groupId", groupId);
        List<UserGroupRelation> relationList = this.list(UserGroupRelation.class, sql, params);
        return relationList.stream().map(UserGroupRelation::getUserId).collect(Collectors.toList());
    }

    /**
     * 根据用户id获取相关联的用户组id
     *
     * @param userId
     * @return
     */
    public List<UserGroupRelation> listGroupIdByUserId(Long userId) {
        String sql = " select * from user_group_relation where user_id =:userId  ";
        Map<String, Object> params = MapTools.simpleMap("userId", userId);
        return this.list(UserGroupRelation.class, sql, params);
    }
}
