package com.bocloud.sms.repository;

import com.megatron.database.core.intf.impl.JdbcGenericDao;
import com.megatron.database.utils.QueryBuilder;
import com.bocloud.sms.entity.UserGroup;
import com.megatron.common.exception.DataBaseException;
import com.megatron.common.model.Pager;
import com.megatron.common.model.Param;
import com.megatron.common.model.SimpleBean;
import com.megatron.common.utils.MapTools;
import com.megatron.framework.core.CurrentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author hongqingyu
 * @time 2020/06/14 20:00
 */
@Repository("userGroupRepository")
public class UserGroupRepository extends JdbcGenericDao<UserGroup, Long> {

    @Autowired
    public UserGroupRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    /**
     * 分页查询用户
     *
     * @param pager
     * @return 用户组
     * @throws DataBaseException 异常
     */
    public List<UserGroup> list(Pager pager) throws DataBaseException {
        String sql = " select a.* from user_group a  where  a.is_deleted = 0 ";
        sql = getQueryBuilder().buildRaw(sql, pager, "a");
        Map<String, Object> paramMap = getQueryBuilder().getParam(pager.getParams());
        return this.list(UserGroup.class, sql, paramMap);
    }

    /**
     * 简易查询用户组
     *
     * @param params 参数
     * @param sorter 排序
     * @return 用户组简易
     * @throws DataBaseException 异常
     */
    public List<SimpleBean> list(List<Param> params, Map<String, String> sorter) throws DataBaseException {
        String sql = " select a.id,a.name from user_group a  where a.is_deleted = 0 ";
        sql = getQueryBuilder().buildRaw(sql, new Pager(1, Integer.MAX_VALUE, params, sorter), "a");
        Map<String, Object> paramMap = getQueryBuilder().getParam(params);
        return this.list(UserGroup.class, sql, paramMap).stream()
                .map(object -> new SimpleBean(object.getId(), object.getName())).collect(Collectors.toList());
    }

    /**
     * 查询用户组数量
     *
     * @param params 参数
     * @return 用户组数量
     */
    public int count(List<Param> params) {
        String sql = "select count(1) from user_group where is_deleted = 0 ";
        Map<String, Object> paramMap = getQueryBuilder().getParam(params);
        sql = getQueryBuilder().buildRaw(sql, params, null, "");
        return this.countQuery(sql, paramMap).intValue();
    }

    /**
     * 统计名称的数量
     *
     * @param name
     * @return
     */
    public int countName(String name, Long id) {
        String sql = " select count(1) from user_group where is_deleted = 0 and name =:name  ";
        Map<String, Object> params = MapTools.simpleMap("name", name);
        if (null != id) {
            sql += " and id != :id ";
            params.put("id", id);
        }
        return this.countQuery(sql, params).intValue();
    }

    /**
     * 根据id查询用户组
     *
     * @param id id
     * @return 用户组
     */
    public UserGroup query(Long id) {
        String sql = " select * from user_group where is_deleted = 0 and id =:id ";
        Map<String, Object> params = MapTools.simpleMap("id", id);
        List<UserGroup> list = this.list(UserGroup.class, sql, params);
        return list.size() > 0 ? list.get(0) : null;
    }

    /**
     * 删除用户组
     *
     * @param id     用户组id
     * @param userId 操作人
     * @return
     */
    public boolean delete(Long id, Long userId) {
        String sql =
                "update user_group set is_deleted = 1, gmt_modify = :gmtModify, mender_id = :menderId where id = :id";
        Map<String, Object> params = MapTools.simpleMap("id", id);
        params.put("gmtModify", new Date());
        params.put("menderId", userId);
        return this.execute(sql, params) > 0;
    }

    /**
     * 查询全部用户组
     *
     * @return
     */
    public List<UserGroup> list() {
        String sql = " select * from user_group where is_deleted = 0";
        return this.list(UserGroup.class, sql);
    }
}
